"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const OdfElement_1 = require("../OdfElement");
const Paragraph_1 = require("./Paragraph");
/**
 * This class represents an item in a list.
 *
 * @example
 * const list = document.getBody()
 *   .addList()
 *   .addItem('First item');
 *
 * @since 0.2.0
 */
class ListItem extends OdfElement_1.OdfElement {
    /**
     * Creates a `ListItem` instance that represents an item in a list.
     *
     * @example
     * new ListItem('First item');
     *
     * @param {string} [text=''] The text content of the list item; defaults to an empty string if omitted
     * @since 0.2.0
     */
    constructor(text) {
        super();
        this.paragraph = new Paragraph_1.Paragraph(text);
        this.append(this.paragraph);
    }
}
exports.ListItem = ListItem;
